@@ -35,7 +35,7 @@ memes = [
     Meme("back_to_work", back_to_work, ("继续干活", "打工人")),
     Meme("perfect", perfect, ("完美",), r"完美的?"),
     Meme("follow", follow, ("关注",)),
-    Meme("my_friend", my_friend, ("我朋友{name}说",), r"我(?:有个)?朋友(?P<name>.*?)说"),
+    Meme("my_friend", my_friend, ("我朋友说",), r"我(?:有个)?朋友(?P<name>.*?)说"),
     Meme("paint", paint, ("这像画吗",)),
     Meme("shock", shock, ("震惊",)),
     Meme("coupon", coupon, ("兑换券",)),
@@ -70,4 +70,7 @@ memes = [
     Meme("repeat", repeat, ("复读",)),
     Meme("anti_kidnap", anti_kidnap, ("防诱拐",)),
     Meme("charpic", charpic, ("字符画",)),
+    Meme("mywife", mywife, ("这是我的老婆",), r"这是(?P<ta>\S+)的(?P<name>\S+)"),
+    Meme("walnutpad", walnutpad, ("胡桃平板",)),
+    Meme("teach", teach, ("讲课", "敲黑板",)),
 ]
